@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '1.5006';
+our $VERSION = '1.5007';
 
 use Carp              ();
 use Fcntl             ();
@@ -13,23 +13,22 @@ use Exporter          ();
 use Data::MessagePack ();
 use Scalar::Util      ();
 
-use Text::Xslate::Util qw(
-    mark_raw unmark_raw
-    html_escape escaped_string
-    uri_escape html_builder
-);
+use Text::Xslate::Util ();
+BEGIN {
+    # all the exportable functions are defined in ::Util
+    our @EXPORT_OK = qw(
+        mark_raw
+        unmark_raw
+        escaped_string
+        html_escape
+        uri_escape
+        html_builder
+    );
+    Text::Xslate::Util->import(@EXPORT_OK);
+}
 
 our @ISA = qw(Text::Xslate::Engine);
 
-our @EXPORT_OK = qw(
-    mark_raw
-    unmark_raw
-    escaped_string
-    html_escape
-    uri_escape
-    html_builder
-);
-
 my $BYTECODE_VERSION = '1.5';
 
 # $bytecode_version + $fullpath + $compiler_and_parser_options
@@ -583,7 +582,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 1.5006.
+This document describes Text::Xslate version 1.5007.
 
 =head1 SYNOPSIS
 
